Introduction
============

A library for IVOA Provenance Data Model supporting PROV-N, PROV-XML, PROV-JSON export

* Free software: MIT license
* Documentation: (incoming).

Features
--------

* An implementation of the `IVOA Provenance Data Model <http://www.ivoa.net/documents/ProvenanceDM/>`_ in Python.
* Serialization support: `PROV-N <http://www.w3.org/TR/prov-n/>`_, `PROV-XML <http://www.w3.org/TR/prov-xml/>`_ and `PROV-JSON <http://www.w3.org/Submission/prov-json/>`_.
* Exporting VOPROV documents into various graphical formats (e.g. PDF, PNG, SVG).
* Convert a VOPROV document to a `Prov Document <https://github.com/trungdong/prov>`_.


Uses
----

A short tutorial for using this package is in development.
